@@ -1,4 +1,8 @@
-package MooseX::Traits;
+package MooseX::Traits; # git description: v0.12-22-g1b6e7ce
+# ABSTRACT: Automatically apply roles at object creation time
+
+our $VERSION = '0.13';
+
 use Moose::Role;
 
 use MooseX::Traits::Util qw(new_class_with_traits);
@@ -8,9 +12,6 @@ use warnings::register;
 
 use namespace::autoclean;
 
-our $VERSION   = '0.11';
-our $AUTHORITY = 'id:JROCKWAY';
-
 has '_trait_namespace' => (
     # no accessors or init_arg
     init_arg => undef,
@@ -61,6 +62,10 @@ sub new_with_traits {
 # need it, write it yourself, but consider applying the roles before
 # you create an instance.
 
+#pod =for Pod::Coverage apply_traits
+#pod
+#pod =cut
+
 sub apply_traits {
     my ($self, $traits, $rebless_params) = @_;
 
@@ -89,9 +94,17 @@ no Moose::Role;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-MooseX::Traits - automatically apply roles at object creation time
+MooseX::Traits - Automatically apply roles at object creation time
+
+=head1 VERSION
+
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -128,7 +141,7 @@ C<with_traits>, and then instantiate that.
 
 There is also C<new_with_traits>, which exists for compatibility
 reasons.  It accepts a C<traits> parameter, creates a new class with
-those traits, and then insantiates it.
+those traits, and then instantiates it.
 
    Class->new_with_traits( traits => [qw/Foo Bar/], foo => 42, bar => 1 )
 
@@ -145,6 +158,8 @@ other methods:
 
 And so on.
 
+=for Pod::Coverage apply_traits
+
 =head1 METHODS
 
 =over 4
@@ -199,32 +214,51 @@ Example:
   $instance2->does('Trait')          # true
   $instance2->does('Another::Trait') # false
 
-=head1 AUTHORS and CONTRIBUTORS
+=head1 AUTHOR
 
-Jonathan Rockway C<< <jrockway@cpan.org> >>
+Jonathan Rockway <jrockway@cpan.org>
 
-Stevan Little C<< <stevan.little@iinteractive.com> >>
+=head1 CONTRIBUTORS
 
-Tomas Doran C<< <bobtfish@bobtfish.net> >>
+=for stopwords Karen Etheridge Florian Ragwitz Tomas Doran Hans Dieter Pearcey Rafael Kitover Stevan Little Alexander Hartmaier
 
-Matt S. Trout C<< <mst@shadowcatsystems.co.uk> >>
+=over 4
 
-Jesse Luehrs C<< <doy at tozt dot net> >>
+=item *
 
-Shawn Moore C<< <sartak@bestpractical.com> >>
+Karen Etheridge <ether@cpan.org>
 
-Florian Ragwitz C<< <rafl@debian.org> >>
+=item *
 
-Chris Prather C<< <chris@prather.org> >>
+Florian Ragwitz <rafl@debian.org>
 
-Yuval Kogman C<< <nothingmuch@woobling.org> >>
+=item *
+
+Tomas Doran <bobtfish@bobtfish.net>
+
+=item *
+
+Hans Dieter Pearcey <hdp@weftsoar.net>
+
+=item *
+
+Rafael Kitover <rkitover@cpan.org>
+
+=item *
+
+Stevan Little <stevan.little@iinteractive.com>
+
+=item *
+
+Alexander Hartmaier <abraxxa@cpan.org>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008 Infinity Interactive, Inc.
+This software is copyright (c) 2008 by Infinity Interactive, Inc. http://www.iinteractive.com.
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
+=cut
